//go:build integration
// +build integration

package integration

import (
	"net/http"
	"testing"

	"gitlab.bit9.local/psc/platform/ems/device-service/internal/client"

	. "github.com/onsi/ginkgo"
	. "github.com/onsi/gomega"
)

var host = "http://ems-device-service:8080/ems-device-service/"

func TestEmsDeviceService(t *testing.T) {
	t.Parallel()
	RegisterFailHandler(Fail)
	RunSpecs(t, "ems-device-service")
}

var _ = Describe("integration test", func() {
	Context("ems-device-service APIs", func() {
		It("should report healthy on healthCheck request", func() {
			req, err := http.NewRequest(http.MethodGet, host+"healthCheck", nil)
			Expect(err).To(BeNil())
			client := http.Client{}
			res, err := client.Do(req)
			Expect(err).To(BeNil())
			Expect(res.StatusCode).To(Equal(http.StatusNoContent))
		})
	})

	Context("device auth client", func() {
		It("should respond 204 on Evict Device request", func() {
			dac := client.NewDeviceAuthClient(client.NewDeviceAuthClientCfg())
			err := dac.EvictDevice("testOrgKey", 1)
			Expect(err).To(BeNil())
		})
	})
})
